@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.54';
+  $Devel::PatchPerl::VERSION = '0.56';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -1727,10 +1727,8 @@ END
 sub _patch_make_ext_pl
 {
   _patch(<<'END');
-diff --git a/make_ext.pl b/make_ext.pl
-index 13a15b4..6425e37 100644
---- a/make_ext.pl
-+++ b/make_ext.pl
+--- make_ext.pl
++++ make_ext.pl
 @@ -377,6 +377,10 @@ WriteMakefile(
  EOM
  	    close $fh or die "Can't close Makefile.PL: $!";
@@ -1758,7 +1756,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.54
+version 0.56
 
 =head1 SYNOPSIS
 
